@@ -1,9 +1,9 @@
 #
 #	Gnu.pm --- The GNU Readline/History Library wrapper module
 #
-#	$Id: Gnu.pm 513 2016-03-06 00:39:56Z hayashi $
+#	$Id: Gnu.pm 543 2016-06-07 15:19:45Z hayashi $
 #
-#	Copyright (c) 1996 Hiroo Hayashi.  All rights reserved.
+#	Copyright (c) 1996-2016 Hiroo Hayashi.  All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or
 #	modify it under the same terms as Perl itself.
@@ -84,34 +84,42 @@ END
 {
     use Exporter ();
     use DynaLoader;
-    our ($VERSION, @ISA, @EXPORT_OK);
 
-    $VERSION = '1.31';		# update Gnu::XS::VERSION also.
+    our $VERSION = '1.32';		# update Gnu::XS::VERSION also.
 
     # Term::ReadLine::Gnu::AU makes a function in
     # `Term::ReadLine::Gnu::XS' as a method.
     # The namespace of Term::ReadLine::Gnu::AU is searched before ones
     # of other classes
-    @ISA = qw(Term::ReadLine::Gnu::AU Term::ReadLine::Stub
-	      Exporter DynaLoader);
 
-    @EXPORT_OK = qw(RL_PROMPT_START_IGNORE RL_PROMPT_END_IGNORE
-		    NO_MATCH SINGLE_MATCH MULT_MATCH
-		    ISFUNC ISKMAP ISMACR
-		    UNDO_DELETE UNDO_INSERT UNDO_BEGIN UNDO_END
-		    RL_STATE_NONE RL_STATE_INITIALIZING
-		    RL_STATE_INITIALIZED RL_STATE_TERMPREPPED
-		    RL_STATE_READCMD RL_STATE_METANEXT
-		    RL_STATE_DISPATCHING RL_STATE_MOREINPUT
-		    RL_STATE_ISEARCH RL_STATE_NSEARCH
-		    RL_STATE_SEARCH RL_STATE_NUMERICARG
-		    RL_STATE_MACROINPUT RL_STATE_MACRODEF
-		    RL_STATE_OVERWRITE RL_STATE_COMPLETING
-		    RL_STATE_SIGHANDLER RL_STATE_UNDOING
-		    RL_STATE_INPUTPENDING RL_STATE_TTYCSAVED
-		    RL_STATE_CALLBACK RL_STATE_VIMOTION
-		    RL_STATE_MULTIKEY RL_STATE_VICMDONCE
-		    RL_STATE_DONE);
+    our @ISA = qw(Term::ReadLine::Gnu::AU Term::ReadLine::Stub
+		  Exporter DynaLoader);
+
+    our %EXPORT_TAGS = (
+	prompt =>	[qw(RL_PROMPT_START_IGNORE RL_PROMPT_END_IGNORE)],
+	match_type =>	[qw(NO_MATCH SINGLE_MATCH MULT_MATCH)],
+	keymap_type =>	[qw(ISFUNC ISKMAP ISMACR)],
+	undo_code =>	[qw(UNDO_DELETE UNDO_INSERT UNDO_BEGIN UNDO_END)],
+	rl_state =>	[qw(RL_STATE_NONE RL_STATE_INITIALIZING
+			    RL_STATE_INITIALIZED RL_STATE_TERMPREPPED
+			    RL_STATE_READCMD RL_STATE_METANEXT
+			    RL_STATE_DISPATCHING RL_STATE_MOREINPUT
+			    RL_STATE_ISEARCH RL_STATE_NSEARCH
+			    RL_STATE_SEARCH RL_STATE_NUMERICARG
+			    RL_STATE_MACROINPUT RL_STATE_MACRODEF
+			    RL_STATE_OVERWRITE RL_STATE_COMPLETING
+			    RL_STATE_SIGHANDLER RL_STATE_UNDOING
+			    RL_STATE_INPUTPENDING RL_STATE_TTYCSAVED
+			    RL_STATE_CALLBACK RL_STATE_VIMOTION
+			    RL_STATE_MULTIKEY RL_STATE_VICMDONCE
+			    RL_STATE_CHARSEARCH RL_STATE_REDISPLAYING
+			    RL_STATE_DONE)],
+	);
+    Exporter::export_ok_tags('prompt');
+    Exporter::export_ok_tags('match_type');
+    Exporter::export_ok_tags('keymap_type');
+    Exporter::export_ok_tags('undo_code');
+    Exporter::export_ok_tags('rl_state');
 
     bootstrap Term::ReadLine::Gnu $VERSION; # DynaLoader
 }
@@ -119,7 +127,7 @@ require Term::ReadLine::Gnu::XS;
 
 #	Global Variables
 
-our(%Attribs, %Features, $readline_version, $utf8_in);
+our($readline_version);
 
 # Each variable in the GNU Readline Library is tied to an entry of
 # this hash (%Attribs).  By accessing the hash entry, you can read
@@ -128,21 +136,21 @@ our(%Attribs, %Features, $readline_version, $utf8_in);
 # for further details.
 
 # Normal (non-tied) entries
-%Attribs  = (
-	     MinLength => 1,
-	     do_expand => 0,
-	     completion_word => [],
-	     term_set => ['', '', '', ''],
-	    );
-%Features = (
-	     appname => 1, minline => 1, autohistory => 1,
-	     getHistory => 1, setHistory => 1, addHistory => 1,
-	     readHistory => 1, writeHistory => 1,
-	     preput => 1, attribs => 1, newTTY => 1,
-	     tkRunning => Term::ReadLine::Stub->Features->{'tkRunning'},
-	     ornaments => Term::ReadLine::Stub->Features->{'ornaments'},
-	     stiflehistory => 1,
-	    );
+our %Attribs  = (
+    MinLength => 1,
+    do_expand => 0,
+    completion_word => [],
+    term_set => ['', '', '', ''],
+    );
+our %Features = (
+    appname => 1, minline => 1, autohistory => 1,
+    getHistory => 1, setHistory => 1, addHistory => 1,
+    readHistory => 1, writeHistory => 1,
+    preput => 1, attribs => 1, newTTY => 1,
+    tkRunning => Term::ReadLine::Stub->Features->{'tkRunning'},
+    ornaments => Term::ReadLine::Stub->Features->{'ornaments'},
+    stiflehistory => 1,
+    );
 
 #
 #	GNU Readline/History Library constant definition
@@ -173,7 +181,7 @@ sub UNDO_INSERT	{ 1; }
 sub UNDO_BEGIN	{ 2; }
 sub UNDO_END	{ 3; }
 
-# for rl_readline_state
+# for rl_readline_state which was implemented since 4.2
 sub RL_STATE_NONE		{ 0x00000; } # no state; before first call
 sub RL_STATE_INITIALIZING	{ 0x00001; } # initializing
 sub RL_STATE_INITIALIZED	{ 0x00002; } # initialization done
@@ -192,19 +200,21 @@ sub RL_STATE_OVERWRITE		{ 0x02000; } # overwrite mode
 sub RL_STATE_COMPLETING		{ 0x04000; } # doing completion
 sub RL_STATE_SIGHANDLER		{ 0x08000; } # in readline sighandler
 sub RL_STATE_UNDOING		{ 0x10000; } # doing an undo
-# The following RL_STATE_* are defined since TRL 6.0
-sub RL_STATE_INPUTPENDING	{ 0x020000; } #	rl_execute_next called
-sub RL_STATE_TTYCSAVED		{ 0x040000; } #	tty special chars saved
-sub RL_STATE_CALLBACK		{ 0x080000; } #	using the callback interface
-sub RL_STATE_VIMOTION		{ 0x100000; } #	reading vi motion arg
-sub RL_STATE_MULTIKEY		{ 0x200000; } #	reading multiple-key command
-sub RL_STATE_VICMDONCE		{ 0x400000; } #	entered vi command mode at least once
-# The following RL_STATE_* is defined since TRL 6.1
-sub RL_STATE_REDISPLAYING	{ 0x800000; } #	updating terminal display
-# The value was changed since TRL 6.0 and 6.1
-# done; accepted line
-sub RL_STATE_DONE { $readline_version < 0x0600 ? 0x80000 : 
-			($readline_version < 0x0601 ? 0x800000 : 0x1000000); }
+sub RL_STATE_INPUTPENDING	{ 0x02_0000; } # rl_execute_next called
+sub RL_STATE_TTYCSAVED		{ 0x04_0000; } # tty special chars saved [5.0]
+sub RL_STATE_CALLBACK		{ 0x08_0000; } # using the callback interface [5.1]
+sub RL_STATE_VIMOTION		{ 0x10_0000; } # reading vi motion arg [5.1]
+sub RL_STATE_MULTIKEY		{ 0x20_0000; } # reading multiple-key command [5.1]
+sub RL_STATE_VICMDONCE		{ 0x40_0000; } # entered vi command mode at least once [5.1]
+sub RL_STATE_CHARSEARCH		{ 0x80_0000; } # vi mode char search [7.0]
+sub RL_STATE_REDISPLAYING	{	       # updating terminal display [6.1]
+    $readline_version < 0x0700 ? 0x80_0000 : 0x100_0000;
+}
+sub RL_STATE_DONE {			       # done; accepted line
+    $readline_version < 0x0501 ? 0x8_0000 : 
+	($readline_version < 0x0601 ? 0x80_0000 :
+	 ($readline_version < 0x0700 ? 0x100_0000 : 0x200_0000));
+}
 
 #
 #	Methods Definition
@@ -221,7 +231,7 @@ this package is being used, C<Term::ReadLine::Gnu> is returned.
 
 sub ReadLine { 'Term::ReadLine::Gnu'; }
 
-=item C<new(NAME,[IN[,OUT]])>
+=item C<new(NAME,[IN,OUT])>
 
 returns the handle for subsequent calls to following functions.
 Argument is the name of the application.  Optionally can be followed
@@ -247,15 +257,28 @@ sub new {
     # calls setenv() before the 1st assignment to $ENV{}.
     $ENV{_TRL_DUMMY} = '';
 
+    # UTF-8 condition conpatible with Term:ReadLine
+    $Attribs{utf8_mode} ||= ${^UNICODE} & 1 || defined ${^ENCODING};
+    #printf "\${^UNICODE}: 0x%X, ", ${^UNICODE};
+    #print "\${^ENCODING}: ", defined ${^ENCODING} ? 'defined' : 'undef', "\n";
+    
     # set tty before calling rl_initialize() not to output some
     # charactores to STDIO.
     # https://rt.cpan.org/Ticket/Display.html?id=96569
     if (!@_) {
-	my ($IN,$OUT) = $self->findConsole();
-	open(IN,"<$IN")   || croak "Cannot open $IN for read";
-	open(OUT,">$OUT") || croak "Cannot open $OUT for write";
-	$self->newTTY(\*IN, \*OUT);
+	my ($in, $out) = $self->findConsole();
+	open(my $IN,"<$in")   || croak "Cannot open $in for read";
+	open(my $OUT,">$out") || croak "Cannot open $out for write";
+	if ($Attribs{utf8_mode}) {
+	    binmode $IN,  ':encoding(UTF-8)'; # not necessary
+	    binmode $OUT, ':encoding(UTF-8)';
+	}
+	$self->newTTY($IN, $OUT);
     } else {
+	# enable UTF-8 mode if input stream has the utf8 layer.
+	my @layers = PerlIO::get_layers($_[0]);
+	$Attribs{utf8_mode} ||= ($layers[$#layers] eq 'utf8');
+    
 	$self->newTTY(@_);
     }
 
@@ -340,13 +363,6 @@ sub readline {			# should be ReadLine
     }
     return undef unless defined $line;
 
-    # from ReadLine.pm: convert to the internal representation from UTF-8
-    # see 'perldoc perlvar'
-    if (($utf8_in || ${^UNICODE} & 1 || defined ${^ENCODING}) && utf8::valid($line)) {
-	utf8::decode($line);
-	utf8::upgrade($line);
-    }
-
     # history expansion
     if ($Attribs{do_expand}) {
 	my $result;
@@ -375,7 +391,7 @@ the actual C<readline> is present.
 
 =cut
 
-use vars '*addhistory';
+#use vars '*addhistory';
 *addhistory = \&AddHistory;	# for backward compatibility
 
 sub AddHistory {
@@ -494,8 +510,28 @@ sub newTTY {
     $| = 1;			# for DB::OUT
     select($sel);
 
-    $Attribs{outstream} = $out;
     $Attribs{instream}  = $in;
+    $Attribs{outstream} = $out;
+}
+
+=item C<enableUTF8>
+
+Enables UTF-8 support.
+
+If STDIN is in UTF-8 by the C<-C> command-line switch or
+C<PERL_UNICODE> environment variable, or C<IN> file handle has C<utf8>
+IO layer, then UTF-8 support is also enabled.  In other cases you need
+this C<enableUTF8> method.
+
+This is an original method of C<Term::ReadLine:Gnu>.
+
+=cut
+
+sub enableUTF8 {
+    my $self = shift;
+    $Attribs{utf8_mode} = 1;
+    binmode $self->IN,  ':encoding(UTF-8)'; # not necessary
+    binmode $self->OUT, ':encoding(UTF-8)';
 }
 
 =back
@@ -528,7 +564,7 @@ sub CallbackHandlerInstall {
 # Documentation is after '__END__' for efficiency.
 
 # for backward compatibility
-use vars qw(*AddDefun *BindKey *UnbindKey *ParseAndBind *StifleHistory);
+#use vars qw(*AddDefun *BindKey *UnbindKey *ParseAndBind *StifleHistory);
 *AddDefun = \&add_defun;
 *BindKey = \&bind_key;
 *UnbindKey = \&unbind_key;
@@ -562,6 +598,7 @@ sub WriteHistory {
 package Term::ReadLine::Gnu::Var;
 use Carp;
 use strict;
+use warnings;
 our %_rl_vars;
 
 %_rl_vars
@@ -629,6 +666,7 @@ our %_rl_vars;
        rl_executing_key				=> ['I', 41], # GRL 6.3
        rl_key_sequence_length			=> ['I', 42], # GRL 6.3
        rl_change_environment			=> ['I', 43], # GRL 6.3
+       utf8_mode				=> ['I', 44], # internal
 
        rl_startup_hook				=> ['F', 0],
        rl_event_hook				=> ['F', 1],
@@ -727,22 +765,18 @@ sub STORE {
     } elsif ($type eq 'F') {
 	return _rl_store_function($value, $id);
     } elsif ($type eq 'IO') {
-	# my @layers;
 	_rl_store_iostream($value, $id);
-	# @layers = PerlIO::get_layers($value);
-	# print "#$id: ", join(':', @layers), "\n";
-
-	# pop the stdio layer pushed by PerlIO_findFILE().
+	# _rl_store_iostream() calls PerlIO_findFILE().  It pushes the
+	# 'stdio' layer on perl 5.10 and later. We must pop the stdio
+	# layer.
 	#   https://rt.cpan.org/Ticket/Display.html?id=59832
-	# pop the stdio layer only when utf8 layer is included for
-	# remote debugging.
+	# But we must pop the 'stdio' layer only when utf8 layer is
+	# included for remote debugging.
 	#   https://rt.cpan.org/Ticket/Display.html?id=110121
-	$utf8_in = 0 if $id == 0;	# to call utf8::decode() for input lines
-	foreach my $layer (PerlIO::get_layers($value)) {
-	    if ($layer eq 'utf8') {
-		$utf8_in = 1 if $id == 0;
+	if ($] > 5.010) {
+	    my @layers = PerlIO::get_layers($value);
+	    if ((grep /^utf8$/, @layers) > 0 && $layers[$#layers] eq 'stdio') {
 		binmode($value,  ":pop");
-		last;
 	    }
 	}
 	return $stream[$id] = $value;
@@ -758,6 +792,7 @@ sub STORE {
 package Term::ReadLine::Gnu;
 use Carp;
 use strict;
+use warnings;
 
 #
 #	set value of %Attribs
@@ -786,7 +821,7 @@ foreach (keys %Term::ReadLine::Gnu::Var::_rl_vars) {
 	 rl_username_completion_function
 	 list_completion_function
          _trp_completion_function);
-    # auto-split subroutine cannot be processed in the map loop above
+    # auto-splited subroutines cannot be processed in the map loop above
     use strict 'refs';
     $Attribs{shadow_redisplay} = \&Term::ReadLine::Gnu::XS::shadow_redisplay;
     $Attribs{Tk_getc} = \&Term::ReadLine::Gnu::XS::Tk_getc;
@@ -796,6 +831,7 @@ foreach (keys %Term::ReadLine::Gnu::Var::_rl_vars) {
 package Term::ReadLine::Gnu::AU;
 use Carp;
 no strict qw(refs vars);
+use warnings;
 
 sub AUTOLOAD {
     { $AUTOLOAD =~ s/.*:://; }	# preserve match data
@@ -807,7 +843,7 @@ sub AUTOLOAD {
     } else {
 	croak "Cannot do `$AUTOLOAD' in Term::ReadLine::Gnu";
     }
-    no warnings 'redefine';	# Why is this line necessary ?
+    no warnings 'redefine';	# Why is this line necessary ???
     *$AUTOLOAD = sub { shift; &$name(@_); };
     goto &$AUTOLOAD;
 }
@@ -1019,7 +1055,7 @@ Manual|http://cnswww.cns.cwru.edu/php/chet/readline/readline.html>.
 
 	str	rl_get_function_name(FunctionPtr function)	# TRG original
 
-=item C<function_of_keyseq(KEYMAP [,MAP])>
+=item C<function_of_keyseq(KEYSEQ [,MAP])>
 
 	(FunctionPtr|Keymap|str data, int type)
 		rl_function_of_keyseq(str keyseq,
@@ -1204,13 +1240,13 @@ Manual|http://cnswww.cns.cwru.edu/php/chet/readline/readline.html>.
 
 	void	rl_deprep_terminal()
 
-=item C<tty_set_default_bindings(KMAP)>
+=item C<tty_set_default_bindings([MAP])>
 
-	void	rl_tty_set_default_bindings([Keymap KMAP])	# GRL 4.0
+	void	rl_tty_set_default_bindings([Keymap|str map = rl_get_keymap()])	# GRL 4.0
 
-=item C<tty_unset_default_bindings(KMAP)>
+=item C<tty_unset_default_bindings([MAP])>
 
-	void	rl_tty_unset_default_bindings([Keymap KMAP])	# GRL 5.0
+	void	rl_tty_unset_default_bindings([Keymap|str map = rl_get_keymap()]) # GRL 5.0
 
 =item C<reset_terminal([TERMINAL_NAME])>
 
@@ -1224,22 +1260,20 @@ Manual|http://cnswww.cns.cwru.edu/php/chet/readline/readline.html>.
 
 =item C<save_state(READLINE_STATE)>
 
-	NOT IMPLEMENTED YET!
-	int	rl_save_state(struct readline_state *sp)	# GRL 6.0
+	READLINE_STATE	rl_save_state()				# GRL 6.0
 
 =item C<restore_state(READLINE_STATE)>
 
-	NOT IMPLEMENTED YET!
-	int	rl_restore_state(struct readline_state *sp)	# GRL 6.0
+	int	rl_restore_state(READLINE_STATE)		# GRL 6.0
 
 =item C<free(MEM)>
 
 	Not implemented since not required for Perl.
-	int	rl_(void *mem)					# GRL 6.0
+	int	rl_free(void *mem)				# GRL 6.0
 
 =item C<replace_line(TEXT [,CLEAR_UNDO])>
 
-	int	rl_replace_line(str text, int clear_undo)	# GRL 4.3
+	int	rl_replace_line(str text, int clear_undo = 0)	# GRL 4.3
 
 =item C<extend_line_buffer(LEN)>
 
@@ -1418,13 +1452,11 @@ When C<MAX> is omitted, the max length of an item in C<@matches> is used.
 
 =item C<history_get_history_state>
 
-	NOT IMPLEMENTED YET!
-	HISTORY_STATE	*history_get_hitory_state()		# GRL 6.3
+	HISTORY_STATE	history_get_hitory_state()		# GRL 6.3
 
 =item C<history_set_history_state>
 
-	NOT IMPLEMENTED YET!
-	void	*history_set_hitory_state(HISTORY_STATE *state)	# GRL 6.3
+	void	history_set_hitory_state(HISTORY_STATE)		# GRL 6.3
 
 =back
 
@@ -1432,7 +1464,7 @@ When C<MAX> is omitted, the max length of an item in C<@matches> is used.
 
 =over 4
 
-=item C<addhistory(STRING[, STRING, ...])>
+=item C<add_history(STRING)>
 
 	void	add_history(str string)
 
@@ -1447,12 +1479,13 @@ When C<MAX> is omitted, the max length of an item in C<@matches> is used.
 =item C<free_history(HISTENT)>
 
 	Not implemented since Term::ReadLine::Gnu does not support the
-	member 'data' of HIST_ENTRY structure, remove_history() covers it.
+	member 'data' of HIST_ENTRY structure. remove_history() frees
+	the memory.
 	histdata_t	free_history_entry(HIST_ENTRY *histent)	# GRL 5.0
 
-=item C<replace_history_entry(WHICH, LINE)>
+=item C<replace_history_entry(WHICH, STRING)>
 
-	str	replace_history_entry(int which, str line)
+	str	replace_history_entry(int which, str string)
 
 =item C<clear_history>
 
@@ -1472,15 +1505,15 @@ of C<unstifle_history()>.
 
 This is equivalent with C<stifle_history(undef)>.
 
+=item C<history_is_stifled>
+
+	int	history_is_stifled()
+
 =item C<SetHistory(LINE1 [, LINE2, ...])>
 
 sets the history of input, from where it can be used if the actual
 C<readline> is present.
 
-=item C<history_is_stifled>
-
-	int	history_is_stifled()
-
 =back
 
 =head4 Information About the History List
@@ -1600,9 +1633,9 @@ F<~/.history>.  Returns true if successful, or false if not.
 
 =over 4
 
-=item C<history_expand(LINE)>
+=item C<history_expand(STRING)>
 
-	(int result, str expansion) history_expand(str line)
+	(int result, str expansion) history_expand(str string)
 
 Note that this function returns C<expansion> in the scalar context.
 
@@ -1612,13 +1645,13 @@ Note that this function returns C<expansion> in the scalar context.
 						   int  cindex,
 						   char qchar = '\0')
 
-=item C<history_tokenize(LINE)>
+=item C<history_tokenize(STRING)>
 
-	(@str)	history_tokenize(str line)
+	(@str)	history_tokenize(str string)
 
-=item C<history_arg_extract(LINE, [FIRST [,LAST]])>
+=item C<history_arg_extract(STRING, [FIRST [,LAST]])>
 
-	str history_arg_extract(str line, int first = 0, int last = '$')
+	str history_arg_extract(str string, int first = 0, int last = '$')
 
 =back
 
@@ -1677,7 +1710,7 @@ Examples:
 	int rl_executing_key (GRL 6.3, read only)
 	str rl_executing_keyseq (GRL 6.3, read only)
 	int rl_key_sequence_length (read only)
-	int rl_readline_state (GRL 4.2, read only)
+	int rl_readline_state (GRL 4.2)
 	int rl_explicit_arg (read only)
 	int rl_numeric_arg (read only)
 	int rl_editing_mode (read only)
@@ -1711,9 +1744,9 @@ Examples:
 	int rl_completion_query_items
 	int rl_completion_append_character
 	int rl_completion_suppress_append (GRL 4.3)
-	int rl_completion_quote_character (GRL 5.0)
+	int rl_completion_quote_character (GRL 5.0, read only)
 	int rl_completion_suppress_quote (GRL 5.0)
-	int rl_completion_found_quote (GRL 5.0)
+	int rl_completion_found_quote (GRL 5.0, read only)
 	int rl_completion_mark_symlink_dirs (GRL 4.3)
 	int rl_ignore_completion_duplicates
 	int rl_filename_completion_desired
@@ -1726,8 +1759,8 @@ Examples:
 
 =head3 History Variables
 
-	int history_base (read only)
-	int history_length (read only)
+	int history_base
+	int history_length
 	int history_max_entries (called `max_input_history', read only)
 	int history_write_timestamps (GRL 5.0)
 	char history_expansion_char
@@ -2004,7 +2037,52 @@ Manual|http://cnswww.cns.cwru.edu/php/chet/readline/readline.html>
 
 =head1 EXPORTS
 
-None.
+No symbols are exported by default.
+The following tags are defined and their symbols can be exported.
+
+=over 4
+
+=item prompt
+
+RL_PROMPT_START_IGNORE RL_PROMPT_END_IGNORE
+
+=item match_type
+
+NO_MATCH SINGLE_MATCH MULT_MATCH
+
+=item keymap_type
+
+ISFUNC ISKMAP ISMACR
+
+=item undo_code
+
+UNDO_DELETE UNDO_INSERT UNDO_BEGIN UNDO_END
+
+=item rl_state
+
+RL_STATE_NONE RL_STATE_INITIALIZING
+RL_STATE_INITIALIZED RL_STATE_TERMPREPPED
+RL_STATE_READCMD RL_STATE_METANEXT
+RL_STATE_DISPATCHING RL_STATE_MOREINPUT
+RL_STATE_ISEARCH RL_STATE_NSEARCH
+RL_STATE_SEARCH RL_STATE_NUMERICARG
+RL_STATE_MACROINPUT RL_STATE_MACRODEF
+RL_STATE_OVERWRITE RL_STATE_COMPLETING
+RL_STATE_SIGHANDLER RL_STATE_UNDOING
+RL_STATE_INPUTPENDING RL_STATE_TTYCSAVED
+RL_STATE_CALLBACK RL_STATE_VIMOTION
+RL_STATE_MULTIKEY RL_STATE_VICMDONCE
+RL_STATE_CHARSEARCH RL_STATE_REDISPLAYING
+RL_STATE_DONE
+
+=back
+
+They can be exported as follows;
+
+	use Term::ReadLine;
+	BEGIN {
+	    import Term::ReadLine::Gnu qw(:keymap_type RL_STATE_INITIALIZED);
+	}
 
 =head1 ENVIRONMENT
 
@@ -2119,7 +2197,7 @@ L<https://rt.perl.org/Public/Bug/Display.html?id=121456> for details.
 
 =head1 LICENSE
 
-Copyright (c) 1996 Hiroo Hayashi.  All rights reserved.
+Copyright (c) 1996-2016 Hiroo Hayashi.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
