@@ -1,10 +1,9 @@
-#!/usr/local/bin/perl
 #
 #	XS.pm : perl function definition for Term::ReadLine::Gnu
 #
-#	$Id: XS.pm 513 2016-03-06 00:39:56Z hayashi $
+#	$Id: XS.pm 543 2016-06-07 15:19:45Z hayashi $
 #
-#	Copyright (c) 1999 Hiroo Hayashi.  All rights reserved.
+#	Copyright (c) 1999-2016 Hiroo Hayashi.  All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or
 #	modify it under the same terms as Perl itself.
@@ -17,18 +16,18 @@ use warnings;
 use AutoLoader 'AUTOLOAD';
 
 our $VERSION;
-$VERSION='1.31';	# added for CPAN
+$VERSION='1.32';	# added for CPAN
 
 # make aliases
 our %Attribs;
 *Attribs = \%Term::ReadLine::Gnu::Attribs;
 
-use vars qw(*read_history);
+#use vars qw(*read_history);
 *read_history = \&read_history_range;
 
 # alias for 8 characters limitation imposed by AutoSplit
-use vars qw(*rl_unbind_key *rl_unbind_function *rl_unbind_command
-	    *history_list *history_arg_extract);
+#use vars qw(*rl_unbind_key *rl_unbind_function *rl_unbind_command
+#	    *history_list *history_arg_extract);
 *rl_unbind_key = \&unbind_key;
 *rl_unbind_function = \&unbind_function;
 *rl_unbind_command = \&unbind_command;
@@ -36,7 +35,7 @@ use vars qw(*rl_unbind_key *rl_unbind_function *rl_unbind_command
 *history_arg_extract = \&hist_arg_extract;
 
 # For backward compatibility.  Using these name (*_in_map) is deprecated.
-use vars qw(*rl_unbind_function_in_map *rl_unbind_command_in_map);
+#use vars qw(*rl_unbind_function_in_map *rl_unbind_command_in_map);
 *rl_unbind_function_in_map = \&unbind_function;
 *rl_unbind_command_in_map  = \&unbind_command;
 
@@ -66,8 +65,10 @@ my $_tstrs_init = 0;
 # Uncomment the following line to enable AutoSplit.  If you are using
 # AutoLoader.pm distributed with Perl 5.004 or earlier, you must
 # update AutoLoader.pm due to its bug.
+# 2016/06/07: now it is time to uncomment. Ignore the warning message,
+# "... some names are not unique ...", during make.
 
-#__END__
+__END__
 
 
 #
